@@ -1,18 +1,16 @@
 package SPVM::File::Find;
 
-our $VERSION = '0.02';
+our $VERSION = "0.021";
 
 1;
 
 =head1 Name
 
-SPVM::File::Find - Short Description
+SPVM::File::Find - Finding Files in Subdirectories
 
 =head1 Description
 
-C<SPVM::File::Find> is the C<File::Find> class in L<SPVM> language.
-
-The C<File::Find> class has methods to get files under a directory.
+The File::Find class of L<SPVM> has methods to find files in subdirectories.
 
 =head1 Usage
 
@@ -22,7 +20,7 @@ The C<File::Find> class has methods to get files under a directory.
   
   my $files_list = StringList->new;
   
-  File::Find->find([$files_list : StringList] method : void ($dir : string, $file_base_name : string) {
+  File::Find->find([has files_list : StringList = $files_list] method : void ($dir : string, $file_base_name : string) {
     my $file = $dir;
     if ($file_base_name) {
       $file .= "/$file_base_name";
@@ -40,13 +38,13 @@ Gets file names:
   
   my $files_list = StringList->new;
   
-  File::Find->find([$files_list : StringList] method : void ($dir : string, $file_base_name : string) {
+  File::Find->find([has files_list : StringList = $files_list] method : void ($dir : string, $file_base_name : string) {
     my $file = $dir;
     if ($file_base_name) {
       $file .= "/$file_base_name";
     }
     
-    $files_list->push($file);
+    $self->{files_list}->push($file);
     
   }, $dir);
   
@@ -74,8 +72,7 @@ Yuki Kimoto C<kimoto.yuki@gmail.com>
 
 =head1 Copyright & License
 
-Copyright 2023-2023 Yuki Kimoto, all rights reserved.
+Copyright (c) 2023 Yuki Kimoto
 
-This program is free software; you can redistribute it and/or modify it
-under the same terms as Perl itself.
+MIT License
 
